<?php
/**
 * Add Featured Content Settings in Customizer
 *
 * @package Catch Themes
 * @subpackage Helena Pro
 * @since Helena Pro 1.0
 */

$wp_customize->add_section( 'helena_featured_content', array(
	'priority' => 800,
	'title'    => esc_html__( 'Featured Content', 'helena-pro' ),
) );

$wp_customize->add_setting( 'featured_content_option', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_option'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'featured_content_option', array(
	'choices'  => helena_featured_section_enable_options(),
	'label'    => esc_html__( 'Enable Featured Content on', 'helena-pro' ),
	'section'  => 'helena_featured_content',
	'settings' => 'featured_content_option',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'featured_content_layout', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_layout'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'featured_content_layout', array(
	'active_callback' => 'helena_is_featured_content_active',
	'choices'         => helena_featured_content_layout_options(),
	'label'           => esc_html__( 'Select Featured Content Layout', 'helena-pro' ),
	'section'         => 'helena_featured_content',
	'settings'        => 'featured_content_layout',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'featured_content_position', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_content_position'],
	'sanitize_callback' => 'helena_sanitize_checkbox'
) );

$wp_customize->add_control( 'featured_content_position', array(
	'active_callback' => 'helena_is_featured_content_active',
	'label'           => esc_html__( 'Check to Move above Footer', 'helena-pro' ),
	'section'         => 'helena_featured_content',
	'settings'        => 'featured_content_position',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'featured_content_slider', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_content_slider'],
	'sanitize_callback' => 'helena_sanitize_checkbox'
) );

$wp_customize->add_control( 'featured_content_slider', array(
	'active_callback' => 'helena_is_featured_content_active',
	'label'           => esc_html__( 'Check to Enable Slider', 'helena-pro' ),
	'section'         => 'helena_featured_content',
	'settings'        => 'featured_content_slider',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'featured_content_type', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_content_type'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'featured_content_type', array(
	'active_callback' => 'helena_is_featured_content_active',
	'choices'         => helena_featured_content_types(),
	'label'           => esc_html__( 'Select Content Type', 'helena-pro' ),
	'section'         => 'helena_featured_content',
	'settings'        => 'featured_content_type',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'featured_content_headline', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_content_headline'],
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'featured_content_headline' , array(
	'active_callback' => 'helena_is_demo_featured_content_inactive',
	'description'     => esc_html__( 'Leave field empty if you want to remove Headline', 'helena-pro' ),
	'label'           => esc_html__( 'Headline for Featured Content', 'helena-pro' ),
	'section'         => 'helena_featured_content',
	'settings'        => 'featured_content_headline',
	'type'            => 'text',
	)
);

$wp_customize->add_setting( 'featured_content_subheadline', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_content_subheadline'],
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'featured_content_subheadline' , array(
	'active_callback' => 'helena_is_demo_featured_content_inactive',
	'description'     => esc_html__( 'Leave field empty if you want to remove Sub-headline', 'helena-pro' ),
	'label'           => esc_html__( 'Sub-headline for Featured Content', 'helena-pro' ),
	'section'         => 'helena_featured_content',
	'settings'        => 'featured_content_subheadline',
	'type'            => 'text',
	)
);

$wp_customize->add_setting( 'featured_content_number', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_content_number'],
	'sanitize_callback' => 'helena_sanitize_number_range',
) );

$wp_customize->add_control( 'featured_content_number' , array(
		'active_callback' => 'helena_is_demo_featured_content_inactive',
		'description'     => esc_html__( 'Save and refresh the page if No. of Featured Content is changed (Max no of Featured Content is 20)', 'helena-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 45px;',
			'min'   => 0,
			'max'   => 20,
			'step'  => 1,
		),
		'label'           => esc_html__( 'No of Featured Content', 'helena-pro' ),
		'section'         => 'helena_featured_content',
		'settings'        => 'featured_content_number',
		'type'            => 'number',
		)
);

$wp_customize->add_setting( 'featured_content_enable_title', array(
		'default'           => $defaults['featured_content_enable_title'],
		'sanitize_callback' => 'helena_sanitize_checkbox',
	) );

$wp_customize->add_control(  'featured_content_enable_title', array(
	'active_callback' => 'helena_is_demo_featured_content_inactive',
	'label'           => esc_html__( 'Check to Enable Title', 'helena-pro' ),
	'section'         => 'helena_featured_content',
	'settings'        => 'featured_content_enable_title',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'featured_content_show', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_content_show'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'featured_content_show', array(
	'active_callback' => 'helena_is_demo_featured_content_inactive',
	'choices'         => helena_featured_content_show(),
	'label'           => esc_html__( 'Display Content', 'helena-pro' ),
	'section'         => 'helena_featured_content',
	'settings'        => 'featured_content_show',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'featured_content_select_category', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_category_list',
) );

$wp_customize->add_control( new helena_customize_dropdown_categories_control( $wp_customize, 'helena_featured_content_select_category', array(
	'active_callback'	=> 'helena_is_featured_category_content_active',
    'label'   	=> esc_html__( 'Select Categories', 'helena-pro' ),
    'name' 		=> 'featured_content_select_category',
    'section'  	=> 'helena_featured_content',
    'settings' 	=> 'featured_content_select_category',
    'type'     	=> 'dropdown-categories',
) ) );


$priority	=	7;

$number = apply_filters( 'helena_get_option', 'featured_content_number' );
for ( $i=1; $i <= $number ; $i++ ) {

	//for featured post content
	$wp_customize->add_setting( 'featured_content_post_'. $i, array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'helena_sanitize_page',
		)
	);

	$wp_customize->add_control( 'helena_featured_content_post_'. $i, array(
		'active_callback'	=> 'helena_is_featured_post_content_active',
		'input_attrs' => array(
        	'style' => 'width: 100px;'
    	),
		'label'    	=> esc_html__( 'Featured Post', 'helena-pro' ) . ' ' . $i ,
		'section'  	=> 'helena_featured_content',
		'settings' 	=> 'featured_content_post_'. $i,
		'type'	   	=> 'text',
		)
	);

	$wp_customize->add_setting( 'featured_content_page_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_page',
	) );

	$wp_customize->add_control( 'helena_featured_content_page_'. $i, array(
		'active_callback'	=> 'helena_is_featured_page_content_active',
		'label'    	=> esc_html__( 'Featured Page', 'helena-pro' ) . ' ' . $i ,
		'section'  	=> 'helena_featured_content',
		'settings' 	=> 'featured_content_page_'. $i,
		'type'	   	=> 'dropdown-pages',
	) );

	if ( $i > 9 ) // use this condition to make sure 10 comes after 9 priority wise
		$priority++;

	$wp_customize->add_setting( 'featured_content_note_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new helena_note_control( $wp_customize, 'featured_content_note_'. $i, array(
		'active_callback'	=> 'helena_is_featured_image_content_active',
        'label'		=> esc_html__( 'Featured Content #', 'helena-pro' ) .  $i,
		'section'  	=> 'helena_featured_content',
        'settings'	=> 'featured_content_note_'. $i,
        'type'     	=> 'description',
		) ) );

	$wp_customize->add_setting( 'featured_content_image_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'featured_content_image_'. $i , array(
		'active_callback'	=> 'helena_is_featured_image_content_active',
		'label'		=> esc_html__( 'Image', 'helena-pro' ),
        'section'   => 'helena_featured_content',
        'settings'  => 'featured_content_image_'. $i,
	) ) );

	$wp_customize->add_setting( 'featured_content_link_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'featured_content_link_'. $i, array(
		'active_callback'	=> 'helena_is_featured_image_content_active',
		'label'		=> esc_html__( 'Link', 'helena-pro' ),
        'section'   => 'helena_featured_content',
        'settings'  => 'featured_content_link_'. $i,
	) );

	$wp_customize->add_setting( 'featured_content_target_'. $i, array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'featured_content_target_'. $i, array(
		'active_callback'	=> 'helena_is_featured_image_content_active',
		'label'		=> esc_html__( 'Check to Open Link in New Window/Tab', 'helena-pro' ),
        'section'   => 'helena_featured_content',
        'settings'  => 'featured_content_target_'. $i,
		'type'		=> 'checkbox',
    ) );

    $wp_customize->add_setting( 'featured_content_title_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'featured_content_title_'. $i, array(
		'active_callback'	=> 'helena_is_featured_image_content_active',
		'label'		=> esc_html__( 'Title', 'helena-pro' ),
        'section'   => 'helena_featured_content',
        'settings'  => 'featured_content_title_'. $i,
		'type'		=> 'text',
    ) );

    $wp_customize->add_setting( 'featured_content_content_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'featured_content_content_'. $i, array(
		'active_callback'	=> 'helena_is_featured_image_content_active',
		'label'		=> esc_html__( 'Content', 'helena-pro' ),
        'section'   => 'helena_featured_content',
        'settings'  => 'featured_content_content_'. $i,
		'type'		=> 'textarea',
    ) );
}