<?php
/**
 * Add Promotion Settings in Customizer
 *
 * @package Catch Themes
 * @subpackage Helena Pro
 * @since Helena Pro 1.0
 */

$wp_customize->add_section( 'helena_promotion_headline_options', array(
	'priority'    => 800,
	'title'   	 	=> esc_html__( 'Promotion Headline', 'helena-pro' ),
) );

$wp_customize->add_setting( 'promotion_headline_option', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['promotion_headline_option'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'promotion_headline_option', array(
	'choices'  	=> helena_featured_section_enable_options(),
	'label'    	=> esc_html__( 'Enable on', 'helena-pro' ),
	'section'  	=> 'helena_promotion_headline_options',
	'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'promotion_headline_type', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['promotion_headline_type'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'promotion_headline_type', array(
	'active_callback' => 'helena_is_promotion_headline_active',
	'choices'         => helena_promotion_headline_types(),
	'label'           => esc_html__( 'Type', 'helena-pro' ),
	'section'         => 'helena_promotion_headline_options',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'promotion_headline_show', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['promotion_headline_show'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'promotion_headline_show', array(
	'active_callback' => 'helena_is_page_post_category_promotion_headline_active',
	'choices'         => helena_featured_content_show(),
	'label'           => esc_html__( 'Display Content', 'helena-pro' ),
	'section'         => 'helena_promotion_headline_options',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'promotion_headline_post', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_page',
) );

$wp_customize->add_control( 'promotion_headline_post', array(
	'active_callback' => 'helena_is_post_promotion_headline_active',
	'input_attrs'     => array( 'style' => 'width: 100px;'),
	'label'           => esc_html__( 'Post ID', 'helena-pro' ),
	'section'         => 'helena_promotion_headline_options',
	'type'            => 'text',
) );

//page content
$wp_customize->add_setting( 'promotion_headline_page', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_page',
) );

$wp_customize->add_control( 'promotion_headline_page', array(
	'active_callback' => 'helena_is_page_promotion_headline_active',
	'label'           => esc_html__( 'Select Page', 'helena-pro' ),
	'section'         => 'helena_promotion_headline_options',
	'type'            => 'dropdown-pages',
) );

$wp_customize->add_setting( 'promotion_headline_category', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_select',
) );

$wp_customize->add_control( 'promotion_headline_category', array(
	'active_callback'   => 'helena_is_category_promotion_headline_active',
	'choices'           => helena_get_category_list(),
	'label'             => esc_html__( 'Select Category', 'helena-pro' ),
	'section'           => 'helena_promotion_headline_options',
	'type'              => 'select',
) );

$wp_customize->add_setting( 'promotion_headline_title', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_title'],
	'sanitize_callback'	=> 'wp_kses_post'
) );

$wp_customize->add_control( 'promotion_headline_title', array(
	'description'     => esc_html__( 'Appropriate Words: 10', 'helena-pro' ),
	'label'           => esc_html__( 'Title', 'helena-pro' ),
	'section'         => 'helena_promotion_headline_options',
	'active_callback' => 'helena_is_custom_promotion_headline_active',
) );

$wp_customize->add_setting( 'promotion_headline_content', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_content'],
	'sanitize_callback'	=> 'wp_kses_post'
) );

$wp_customize->add_control( 'promotion_headline_content', array(
	'description'     => esc_html__( 'Appropriate Words: 15', 'helena-pro' ),
	'label'           => esc_html__( 'Content', 'helena-pro' ),
	'section'         => 'helena_promotion_headline_options',
	'active_callback' => 'helena_is_custom_promotion_headline_active',
	'type'            => 'textarea',
) );

$wp_customize->add_setting( 'promotion_headline_button_1', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_button_1'],
	'sanitize_callback'	=> 'sanitize_text_field'
) );

$wp_customize->add_control( 'promotion_headline_button_1', array(
	'description'     => esc_html__( 'Appropriate Words: 3', 'helena-pro' ),
	'label'           => esc_html__( 'Button 1 Text', 'helena-pro' ),
	'section'         => 'helena_promotion_headline_options',
	'active_callback' => 'helena_is_custom_promotion_headline_active',
) );

$wp_customize->add_setting( 'promotion_headline_url_1', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_url_1'],
	'sanitize_callback'	=> 'esc_url_raw'
) );

$wp_customize->add_control( 'promotion_headline_url_1', array(
	'label'           => esc_html__( 'Button 1 Link', 'helena-pro' ),
	'section'         => 'helena_promotion_headline_options',
	'type'            => 'text',
	'active_callback' => 'helena_is_custom_promotion_headline_active',
) );

$wp_customize->add_setting( 'promotion_headline_target_1', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_target_1'],
	'sanitize_callback' => 'helena_sanitize_checkbox',
) );

$wp_customize->add_control( 'promotion_headline_target_1', array(
	'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'helena-pro' ),
	'section'         => 'helena_promotion_headline_options',
	'type'            => 'checkbox',
	'active_callback' => 'helena_is_custom_promotion_headline_active',
) );

$wp_customize->add_setting( 'promotion_headline_button_2', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_button_2'],
	'sanitize_callback'	=> 'sanitize_text_field'
) );

$wp_customize->add_control( 'promotion_headline_button_2', array(
	'description'     => esc_html__( 'Appropriate Words: 3', 'helena-pro' ),
	'label'           => esc_html__( 'Button 2 Text ', 'helena-pro' ),
	'section'         => 'helena_promotion_headline_options',
	'active_callback' => 'helena_is_custom_promotion_headline_active',
) );

$wp_customize->add_setting( 'promotion_headline_url_2', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_url_2'],
	'sanitize_callback'	=> 'esc_url_raw'
) );

$wp_customize->add_control( 'promotion_headline_url_2', array(
	'label'           => esc_html__( 'Button 2 Link', 'helena-pro' ),
	'section'         => 'helena_promotion_headline_options',
	'type'            => 'text',
	'active_callback' => 'helena_is_custom_promotion_headline_active',
) );

$wp_customize->add_setting( 'promotion_headline_target_2', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['promotion_headline_target_2'],
	'sanitize_callback' => 'helena_sanitize_checkbox',
) );

$wp_customize->add_control( 'promotion_headline_target_2', array(
	'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'helena-pro' ),
	'section'         => 'helena_promotion_headline_options',
	'type'            => 'checkbox',
	'active_callback' => 'helena_is_custom_promotion_headline_active',
) );