<?php
/**
 * Implement Default Theme/Customizer Options
 *
 * @package Catch Themes
 * @subpackage Helena Pro
 * @since Helena Pro 1.0
 */


/**
 * Returns the default options for helena.
 *
 * @since Helena Pro 1.0
 */
function helena_get_default_theme_options( $parameter = null ) {
	$theme_data = wp_get_theme();

	$default_theme_options = array(
		//Site Info
		'disable_tagline_header'                             => 0,
		'disable_tagline_footer'                             => 0,
		'move_title_tagline'                                 => 0,

		//Header Image
		'enable_header_image'                                => 'exclude-home-page-post',
		'featured_image_size'                                => 'helena-slider',
		'featured_header_title'                              => esc_html( get_bloginfo( 'name') ),
		'featured_header_content'                            => esc_html( get_bloginfo( 'description' ) ),
		'featured_header_button_text'                        => esc_html__( 'View More', 'helena-pro' ),
		'featured_header_button_link'                        => '#',
		'featured_header_button_target'                      => 0,

		//Breadcrumb Options
		'breadcrumb_option'                                  => 0,
		'breadcrumb_on_homepage'                             => 0,
		'breadcrumb_seperator'                               => '&raquo;',

		//Comment Options
		'comment_option'                                     => 'use-wordpress-setting',
		'disable_website_field'                              => 0,

		//Custom CSS
		'custom_css'                                         => '',

		//Excerpt Options
		'excerpt_length'                                     => '40',
		'excerpt_more_text'                                  => esc_html__( 'Continue reading', 'helena-pro' ),

		//Font Family Options
		'body_font'                                          => 'rubik',
		'title_font'                                         => 'rubik',
		'tagline_font'                                       => 'rubik',
		'content_title_font'                                 => 'playfair-display',
		'content_font'                                       => 'rubik',
		'headings_font'                                      => 'rubik',
		'reset_typography'                                   => 0,

		//Homepage / Frontpage Settings
		'front_page_category'                                => '0',

		//Menu Options
		'primary_menu_disable'                               => 0,
		'disable_primary_search'                             => 1,

		//Layout Options
		'theme_layout'                                       => 'no-sidebar-full-width',
		'woocommerce_layout'                                 => 'no-sidebar-full-width',
		'single_page_post_layout'                            => 'no-sidebar-full-width',
		'content_layout'                                     => 'excerpt-image-top',
		'single_post_image_layout'                           => 'disabled',

		//Promotion Headline Options
		'promotion_headline_option'                          => 'homepage',
		'promotion_headline_type'                            => 'demo',
		'promotion_headline_show'                            => 'excerpt',
		'promotion_headline_title'                           => '',
		'promotion_headline_content'                         => '',
		'promotion_headline_button_1'                        => esc_html__( 'Buy Now', 'helena-pro' ),
		'promotion_headline_url_1'                           => '#',
		'promotion_headline_target_1'                        => 1,
		'promotion_headline_button_2'                        => esc_html__( 'Buy Now', 'helena-pro' ),
		'promotion_headline_url_2'                           => '#',
		'promotion_headline_target_2'                        => 1,

		//Feed Redirect
		'feed_redirect'                                      => '',

		//Pagination Options
		'pagination_type'                                    => 'default',

		//Search Options
		'search_text'                                        => esc_html__( 'Search...', 'helena-pro' ),

		//Single Post Navigation
		'disable_single_post_navigation'                     => 0,

		//Scrollup Options
		'disable_scrollup'                                   => 0,

		//Update Notifier
		'update_notifier'                                    => 0,

		//Footer Editor Options
		'footer_content'                                     => sprintf( _x( 'Copyright &copy; %1$s %2$s.', '1: Year, 2: Site Title with home URL', 'helena-pro' ), date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' ) . ' ' . esc_attr( $theme_data->get( 'Name') ) . '&nbsp;' . __( 'by', 'helena-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_attr( $theme_data->get( 'Author' ) ) .'</a>',
		'reset_footer_content'                               => 0,

		//Basic Color Options
		'color_scheme'                                       => 'light',
		'background_color'                                   => '#f3f3f3',
		'text_color'                                         => '#666666',
		'link_color'                                         => '#e8554e',
		'link_hover_color'                                   => '#666666',

		//Header Color Options
		'header_textcolor'                                   => '#ffffff',
		'header_background_color'                            => '#000000',
		'site_title_hover_color'                             => '#e8554e',
		'tagline_color'                                      => '#dddddd',

		// Header Image Color Options
		'header_image_background_color'                      => '#000000',
		'header_image_text_color'                            => '#ffffff',
		'header_image_content_wrapper_background_color'      => '#666666',
		'header_image_link_color'                            => '#e8554e',
		'header_image_link_hover_color'                      => '#ffffff',
		'header_image_title_color'                           => '#ffffff',
		'header_image_title_hover_color'                     => '#e8554e',
		'header_image_button_background_color'               => '',
		'header_image_button_border_color'                   => '#ffffff',
		'header_image_button_text_color'                     => '#ffffff',
		'header_image_button_hover_background_color'         => '#e8554e',
		'header_image_button_hover_border_color'             => '#e8554e',
		'header_image_button_hover_text_color'               => '#ffffff',

		// Breadcrumb Color Options.
		'breadcrumb_background_color'                        => '#000000',
		'breadcrumb_text_color'                              => '#ffffff',
		'breadcrumb_link_color'                              => '#e8554e',
		'breadcrumb_link_hover_color'                        => '#ffffff',

		// Content Color Options
		'content_wrapper_background_color'                   => '#ffffff',
		'content_background_color'                           => '',
		'alternate_post_background_color'                    => '#f9f9f9',
		'content_title_color'                                => '#000000',
		'content_title_hover_color'                          => '#e8554e',
		'content_meta_color'                                 => '#666666',
		'content_meta_hover_color'                           => '#e8554e',

		//Social Menu Color Options
		'social_menu_color'                                  => '#666666',
		'social_menu_border_color'                           => '#666666',
		'social_menu_hover_color'                            => '#e8554e',
		'social_menu_hover_border_color'                     => '#e8554e',
		'social_menu_brand_color'                            => 'disable',

		//Sidebar Color Options
		'sidebar_background_color'                           => '',
		'sidebar_widget_title_color'                         => '#000000',
		'sidebar_widget_text_color'                          => '#666666',
		'sidebar_widget_link_color'                          => '#444444',
		'sidebar_widget_link_hover_color'                    => '#e8554e',

		//Pagination Color Options
		'pagination_background_color'                        => '#000000',
		'pagination_link_color'                              => '#ffffff',
		'pagination_text_color'                              => '#666666',
		'pagination_hover_background_color'                  => '#e8554e',
		'pagination_hover_link_color'                        => '#ffffff',

		//Footer Color Options
		'footer_background_color'                            => '',
		'footer_text_color'                                  => '#666666',
		'footer_link_color'                                  => '#444444',
		'footer_link_hover_color'                            => '#e8554e',
		'footer_sidebar_area_background_color'               => '#000000',
		'footer_widget_title_color'                          => '#ffffff',
		'footer_widget_text_color'                           => '#bbbbbb',
		'footer_widget_link_color'                           => '#dddddd',
		'footer_widget_link_hover_color'                     => '#e8554e',

		//Promotion Headline Color Options
		'promotion_headline_background_color'                => '#ffffff',
		'promotion_headline_text_color'                      => '#666666',
		'promotion_headline_link_color'                      => '#e8554e',
		'promotion_headline_link_hover_color'                => '#666666',
		'promotion_headline_button_background_color'         => '',
		'promotion_headline_button_link_color'               => '#666666',
		'promotion_headline_button_border_color'             => '#666666',
		'promotion_headline_button_hover_background_color'   => '#e8554e',
		'promotion_headline_button_hover_link_color'         => '#ffffff',
		'promotion_headline_button_hover_border_color'       => '#e8554e',

		//Scrollup Color Options
		'scrollup_background_color'                          => '',
		'scrollup_text_color'                                => '#666666',
		'scrollup_border_color'                              => '#666666',
		'scrollup_hover_background_color'                    => '',
		'scrollup_hover_text_color'                          => '#e5e5e5',
		'scrollup_hover_border_color'                        => '#e5e5e5',

		//Header Highlight Content Color Options
		'header_highlight_background_color'                  => '#ffffff',
		'header_highlight_title_color'                       => '#ffffff',
		'header_highlight_title_hover_color'                 => '#e8554e',
		'header_highlight_text_color'                        => '#666666',
		'header_highlight_headline_color'                    => '#000000',
		'header_highlight_headline_hover_color'              => '#e8554e',
		'header_highlight_content_background_color'          => '#ffffff',
		'header_highlight_link_color'                        => '#e8554e',
		'header_highlight_link_hover_color'                  => '#666666',
		'header_highlight_meta_color'                        => '#ffffff',
		'header_highlight_meta_hover_color'                  => '#e8554e',
		'header_highlight_small_title_color'                 => '#000000',
		'header_highlight_small_title_hover_color'           => '#e8554e',
		'header_highlight_small_meta_color'                  => '#666666',
		'header_highlight_small_meta_hover_color'            => '#e8554e',

		//Slider Color Options
		'slider_background_color'                            => '#000000',
		'slider_text_color'                                  => '#ffffff',
		'slider_content_wrapper_background_color'            => '#666666',
		'slider_link_color'                                  => '#e8554e',
		'slider_link_hover_color'                            => '#ffffff',
		'slider_title_color'                                 => '#ffffff',
		'slider_title_hover_color'                           => '#e8554e',
		'slider_button_background_color'                     => '',
		'slider_button_text_color'                           => '#ffffff',
		'slider_button_border_color'                         => '#ffffff',
		'slider_button_hover_background_color'               => '#e8554e',
		'slider_button_hover_text_color'                     => '#ffffff',
		'slider_button_hover_border_color'                   => '#e8554e',

		//Hero Conent Color Options
		'hero_content_background_color'                      => '#ffffff',
		'hero_content_title_color'                           => '#000000',
		'hero_content_title_hover_color'                     => '#e8554e',
		'hero_content_text_color'                            => '#666666',
		'hero_content_link_color'                            => '#e8554e',
		'hero_content_link_hover_color'                      => '#666666',

		//Featured Content Color Options
		'featured_content_background_color'                  => '#ffffff',
		'featured_content_text_color'                        => '#ffffff',
		'featured_content_headline_color'                    => '#000000',
		'featured_content_sub_headline_color'                => '#666666',
		'featured_content_title_color'                       => '#000000',
		'featured_content_title_hover_color'                 => '#e8554e',
		'featured_content_link_color'                        => '#e8554e',
		'featured_content_link_hover_color'                  => '#666666',

		//Primary Menu Color Options
		'menu_background_color'                              => '',
		'menu_color'                                         => '#ffffff',
		'menu_hover_active_background_color'                 => '',
		'menu_hover_active_text_color'                       => '#e8554e',
		'sub_menu_background_color'                          => '#ffffff',
		'sub_menu_border_color'                              => '#d1d1d1',
		'sub_menu_text_color'                                => '#242424',
		'sub_menu_hover_background_color'                    => '#ffffff',
		'sub_menu_hover_border_color'                        => '#d1d1d1',
		'sub_menu_hover_text_color'                          => '#e8554e',

		// Mobile Menu
		'mobile_menu_button_background_color'                => '',
		'mobile_menu_button_border_color'                    => '#d1d1d1',
		'mobile_menu_button_text_color'                      => '#ffffff',
		'mobile_menu_hover_button_background_color'          => '',
		'mobile_menu_hover_button_border_color'              => '#e8554e',
		'mobile_menu_hover_button_text_color'                => '#e8554e',
		'mobile_menu_focus_button_background_color'          => '#1a1a1a',
		'mobile_menu_focus_button_border_color'              => '#1a1a1a',
		'mobile_menu_focus_button_text_color'                => '#e8554e',
		'mobile_menu_dropdown_toggle_background_color'       => '',
		'mobile_menu_dropdown_toggle_color'                  => '#ffffff',
		'mobile_menu_dropdown_toggle_background_hover_color' => '',
		'mobile_menu_dropdown_toggle_hover_color'            => '#e8554e',

		//Header Highlight Content Options
		'header_highlight_content_option'                    => 'disabled',
		'header_highlight_content_type'                      => 'demo-header-highlight-content',
		'header_highlight_content_headline'                  => '',
		'header_highlight_content_subheadline'               => '',
		'header_highlight_content_number'                    => '3',
		'header_highlight_content_select_category'           => '0',
		'header_highlight_content_show'                      => 'hide-content',
		'header_highlight_content_hide_category'             => 0,
		'header_highlight_content_hide_tags'                 => 1,
		'header_highlight_content_hide_author'               => 1,
		'header_highlight_content_hide_date'                 => 0,

		//Featured Slider Options
		'featured_slider_option'                             => 'disabled',
		'featured_slider_image_loader'                       => 'true',
		'featured_slider_transition_effect'                  => 'fadeout',
		'featured_slider_transition_delay'                   => '4',
		'featured_slider_transition_length'                  => '1',
		'featured_slider_type'                               => 'demo-featured-slider',
		'featured_slider_number'                             => '4',
		'featured_slider_select_category'                    => '0',
		'exclude_slider_post'                                => 0,

		//Hero Content Options
		'hero_content_option'                                => 'disabled',
		'hero_content_type'                                  => 'demo-hero-content',
		'hero_content_number'                                => '1',
		'hero_content_enable_title'                          => 1,
		'hero_content_show'                                  => 'excerpt',
		'hero_content_select_category'                       => '0',
		'disable_read_more'                                  => 0,

		//Featured Content Options
		'featured_content_option'                            => 'disabled',
		'featured_content_layout'                            => 'three-columns',
		'featured_content_position'                          => 0,
		'featured_content_slider'                            => 1,
		'featured_content_headline'                          => '',
		'featured_content_subheadline'                       => '',
		'featured_content_type'                              => 'demo-featured-content',
		'featured_content_number'                            => '3',
		'featured_content_enable_title'                      => 1,
		'featured_content_show'                              => 'hide-content',
		'featured_content_select_category'                   => '0',

		//Portfolio
		'portfolio_option'                                   => 'disabled',
		'portfolio_layout'                                   => 'four-columns',
		'portfolio_position'                                 => 0,
		'portfolio_slider'                                   => 1,
		'portfolio_headline'                                 => '',
		'portfolio_subheadline'                              => '',
		'portfolio_type'                                     => 'demo-portfolio',
		'portfolio_number'                                   => '4',
		'portfolio_enable_title'                             => 1,
		'portfolio_select_category'                          => '0',
		'portfolio_hide_category'                            => 0,
		'portfolio_hide_tags'                                => 1,
		'portfolio_hide_author'                              => 1,
		'portfolio_hide_date'                                => 0,

		//Logo Slider
		'logo_slider_option'                                 => 'disabled',
		'logo_slider_type'                                   => 'demo',
		'logo_slider_visible_items'                          => '4',
		'logo_slider_transition_delay'                       => '4',
		'logo_slider_transition_length'                      => '1',
		'logo_slider_title'                                  => '',
		'logo_slider_number'                                 => '5',
		'logo_slider_select_category'                        => '0',

		//Reset all settings
		'reset_all_settings'                                 => 0,
	);

	if ( null == $parameter ) {
		return apply_filters( 'helena_default_theme_options', $default_theme_options );
	} else {
		return isset( $default_theme_options[ $parameter ] ) ? $default_theme_options[ $parameter ] : false;
	}
}

/**
 * Returns an array of feature header enable options
 *
 * @since Helena Pro 1.0
 */
function helena_enable_header_image_options() {
	$options = array(
		'homepage'               => esc_html__( 'Homepage / Frontpage', 'helena-pro' ),
		'exclude-home'           => esc_html__( 'Excluding Homepage', 'helena-pro' ),
		'exclude-home-page-post' => esc_html__( 'Excluding Homepage, Page/Post Featured Image', 'helena-pro' ),
		'entire-site'            => esc_html__( 'Entire Site', 'helena-pro' ),
		'entire-site-page-post'  => esc_html__( 'Entire Site, Page/Post Featured Image', 'helena-pro' ),
		'pages-posts'            => esc_html__( 'Pages and Posts', 'helena-pro' ),
		'disabled'               => esc_html__( 'Disabled', 'helena-pro' ),
	);

	return apply_filters( 'helena_enable_header_image_options', $options );
}

/**
 * Returns an array of feature image size
 *
 * @since Helena Pro 1.0
 */
function helena_featured_image_size_options() {
	$options['helena-slider'] = esc_html__( 'Slider size (1170x658)', 'helena-pro' );
	$options['full'] = esc_html__( 'Full size', 'helena-pro' );

	return apply_filters( 'helena_featured_image_size_options', $options );
}

/**
 * Returns an array of color schemes registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_color_schemes() {
	$options = array(
		'light' => esc_html__( 'Light', 'helena-pro' ),
		'dark'  => esc_html__( 'Dark', 'helena-pro' ),
	);

	return apply_filters( 'helena_color_schemes', $options );
}

/**
 * Returns list of basic color options currently supported
 *
 * @since Helena Pro 1.0
*/
function helena_get_color_options( $filter ) {
	$options = array(); // Initialize options
	switch ( $filter ) {
		case 'color_headings':
			$options = array(
				'basic_color'              => esc_html__( 'Basic Color', 'helena-pro' ),
				'header_color'             => esc_html__( 'Header Color', 'helena-pro' ),
				'header_image_color'       => esc_html__( 'Header Image Color', 'helena-pro' ),
				'breadcrumb_color'         => esc_html__( 'Breadcrumb Color', 'helena-pro' ),
				'content_color'            => esc_html__( 'Content Color', 'helena-pro' ),
				'social_color'             => esc_html__( 'Social Menu Color', 'helena-pro' ),
				'sidebar_color'            => esc_html__( 'Sidebar Color', 'helena-pro' ),
				'pagination_color'         => esc_html__( 'Pagination Color', 'helena-pro' ),
				'footer_color'             => esc_html__( 'Footer Color', 'helena-pro' ),
				'promotion_headline_color' => esc_html__( 'Promotion Headline Color', 'helena-pro' ),
				'scrollup_color'           => esc_html__( 'Scrollup Color', 'helena-pro' ),
				'header_highlight_color'   => esc_html__( 'Header Highlight Color', 'helena-pro' ),
				'slider_color'             => esc_html__( 'Slider Color', 'helena-pro' ),
				'hero_content_color'       => esc_html__( 'Hero Content Color', 'helena-pro' ),
				'featured_content_color'   => esc_html__( 'Featured Content Color', 'helena-pro' ),
				'menu_color'               => esc_html__( 'Primary Menu Color', 'helena-pro' ),
				'mobile_menu_color'        => esc_html__( 'Mobile Menu Color', 'helena-pro' ),
			);
			break;

		case 'basic_color':
			$options =	array(
				'text_color'       => esc_html__( 'Text Color', 'helena-pro' ),
				'link_color'       => esc_html__( 'Link Color', 'helena-pro' ),
				'link_hover_color' => esc_html__( 'Link Hover Color', 'helena-pro' ),
			);
			break;

		case 'header_color':
			$options = array(
				'header_background_color' => esc_html__( 'Header Background color', 'helena-pro' ),
				'site_title_hover_color'  => esc_html__( 'Site Title Hover Color', 'helena-pro' ),
				'tagline_color'           => esc_html__( 'Tagline Color', 'helena-pro' )
			);
			break;

		case 'header_image_color':
			$options = array(
				'header_image_background_color'                 => esc_html__( 'Background color', 'helena-pro' ),
				'header_image_text_color'                       => esc_html__( 'Text color', 'helena-pro' ),
				'header_image_content_wrapper_background_color' => esc_html__( 'Content Wrapper Background color', 'helena-pro' ),
				'header_image_link_color'                       => esc_html__( 'Link color', 'helena-pro' ),
				'header_image_link_hover_color'                 => esc_html__( 'Link Hover color', 'helena-pro' ),
				'header_image_title_color'                      => esc_html__( 'Title color', 'helena-pro' ),
				'header_image_title_hover_color'                => esc_html__( 'Title Hover color', 'helena-pro' ),
				'header_image_button_background_color'          => esc_html__( 'Button Background color', 'helena-pro' ),
				'header_image_button_border_color'              => esc_html__( 'Button Border Background color', 'helena-pro' ),
				'header_image_button_text_color'                => esc_html__( 'Button Border Text color', 'helena-pro' ),
				'header_image_button_hover_background_color'    => esc_html__( 'Button Hover Background color', 'helena-pro' ),
				'header_image_button_hover_border_color'        => esc_html__( 'Button Hover Border color', 'helena-pro' ),
				'header_image_button_hover_text_color'          => esc_html__( 'Button Hover Text color', 'helena-pro' ),
			);
			break;

		case 'breadcrumb_color':
			$options =	array(
				'breadcrumb_background_color' => esc_html__( 'Wrapper Background Color', 'helena-pro' ),
				'breadcrumb_text_color'       => esc_html__( 'Background Color', 'helena-pro' ),
				'breadcrumb_link_color'       => esc_html__( 'Title Color', 'helena-pro' ),
				'breadcrumb_link_hover_color' => esc_html__( 'Title Hover Color', 'helena-pro' ),
			);
			break;

		case 'content_color':
			$options =	array(
				'content_wrapper_background_color' => esc_html__( 'Wrapper Background Color', 'helena-pro' ),
				'content_background_color'         => esc_html__( 'Background Color', 'helena-pro' ),
				'alternate_post_background_color'  => esc_html__( 'Alternate Post Background Color', 'helena-pro' ),
				'content_title_color'              => esc_html__( 'Title Color', 'helena-pro' ),
				'content_title_hover_color'        => esc_html__( 'Title Hover Color', 'helena-pro' ),
				'content_meta_color'               => esc_html__( 'Meta Color', 'helena-pro' ),
				'content_meta_hover_color'         => esc_html__( 'Meta Hover Color', 'helena-pro' ),
			);
			break;

		case 'social_color':
			$options = array(
				'social_menu_color'              => esc_html__( 'Social Menu Color', 'helena-pro' ),
				'social_menu_border_color'       => esc_html__( 'Social Menu Border Color', 'helena-pro' ),
				'social_menu_hover_color'        => esc_html__( 'Social Menu Hover Color', 'helena-pro' ),
				'social_menu_hover_border_color' => esc_html__( 'Social Menu Hover Border Color', 'helena-pro' ),
			);
			break;

		case 'sidebar_color':
			$options = array(
				'sidebar_background_color'        => esc_html__( 'Background Color', 'helena-pro' ),
				'sidebar_widget_title_color'      => esc_html__( 'Widget Title Color', 'helena-pro' ),
				'sidebar_widget_text_color'       => esc_html__( 'Widget Text Color', 'helena-pro' ),
				'sidebar_widget_link_color'       => esc_html__( 'Widget Link Color', 'helena-pro' ),
				'sidebar_widget_link_hover_color' => esc_html__( 'Widget Link Hover Color', 'helena-pro' ),
				);
			break;

		case 'pagination_color':
			$options = array(
				'pagination_background_color'       => esc_html__( 'Background Color', 'helena-pro' ),
				'pagination_link_color'             => esc_html__( 'Link Color', 'helena-pro' ),
				'pagination_hover_background_color' => esc_html__( 'Hover Background Color', 'helena-pro' ),
				'pagination_hover_link_color'       => esc_html__( 'Hover Link Color', 'helena-pro' ),
				'pagination_text_color'             => esc_html__( 'Text Color', 'helena-pro' ),
			);
			break;

		case 'footer_color':
			$options = array(
				'footer_background_color'              => esc_html__( 'Background Color', 'helena-pro' ),
				'footer_text_color'                    => esc_html__( 'Text Color', 'helena-pro' ),
				'footer_link_color'                    => esc_html__( 'Link Color', 'helena-pro' ),
				'footer_link_hover_color'              => esc_html__( 'Link Hover Color', 'helena-pro' ),
				'footer_sidebar_area_background_color' => esc_html__( 'Sidebar Area Background Color', 'helena-pro' ),
				'footer_widget_title_color'            => esc_html__( 'Widget Title Color', 'helena-pro' ),
				'footer_widget_text_color'             => esc_html__( 'Widget Text Color', 'helena-pro' ),
				'footer_widget_link_color'             => esc_html__( 'Widget Link Color', 'helena-pro' ),
				'footer_widget_link_hover_color'       => esc_html__( 'Widget Link Hover Color', 'helena-pro' ),
			);
			break;

		case 'promotion_headline_color':
			$options = array(
				'promotion_headline_background_color'              => esc_html__( 'Background Color', 'helena-pro' ),
				'promotion_headline_text_color'                    => esc_html__( 'Text Color', 'helena-pro' ),
				'promotion_headline_link_color'                    => esc_html__( 'Link Color', 'helena-pro' ),
				'promotion_headline_link_hover_color'                    => esc_html__( 'Link Hover Color', 'helena-pro' ),
				'promotion_headline_button_background_color'       => esc_html__( 'Button Background Color', 'helena-pro' ),
				'promotion_headline_button_link_color'             => esc_html__( 'Button Link Color', 'helena-pro' ),
				'promotion_headline_button_border_color'             => esc_html__( 'Button Border Color', 'helena-pro' ),
				'promotion_headline_button_hover_background_color' => esc_html__( 'Button Hover Background Color', 'helena-pro' ),
				'promotion_headline_button_hover_link_color'       => esc_html__( 'Button Hover Link Color', 'helena-pro' ),
				'promotion_headline_button_hover_border_color'       => esc_html__( 'Button Hover Border Color', 'helena-pro' ),
			);
			break;

		case 'scrollup_color':
			$options = array(
				'scrollup_background_color'       => esc_html__( 'Background Color', 'helena-pro' ),
				'scrollup_text_color'             => esc_html__( 'Text Color', 'helena-pro' ),
				'scrollup_border_color'           => esc_html__( 'Border Color', 'helena-pro' ),
				'scrollup_hover_background_color' => esc_html__( 'Hover Background Color', 'helena-pro' ),
				'scrollup_hover_text_color'       => esc_html__( 'Hover Text Color', 'helena-pro' ),
				'scrollup_hover_border_color'     => esc_html__( 'Hover Border Color', 'helena-pro' ),
			);
			break;

		case 'header_highlight_color':
			$options = array(
				'header_highlight_background_color'         => esc_html__( 'Background Color', 'helena-pro' ),
				'header_highlight_title_color'              => esc_html__( 'Title Color', 'helena-pro' ),
				'header_highlight_title_hover_color'        => esc_html__( 'Title Hover Color', 'helena-pro' ),
				'header_highlight_headline_color'           => esc_html__( 'Headline Color', 'helena-pro' ),
				'header_highlight_headline_hover_color'     => esc_html__( 'Headline Hover Color', 'helena-pro' ),
				'header_highlight_content_background_color' => esc_html__( 'Content Background Color', 'helena-pro' ),
				'header_highlight_text_color'               => esc_html__( 'Text Color', 'helena-pro' ),
				'header_highlight_link_color'               => esc_html__( 'Link Color', 'helena-pro' ),
				'header_highlight_link_hover_color'         => esc_html__( 'Link Hover Color', 'helena-pro' ),
				'header_highlight_meta_color'               => esc_html__( 'Meta Color', 'helena-pro' ),
				'header_highlight_meta_hover_color'         => esc_html__( 'Meta Hover Color', 'helena-pro' ),
				'header_highlight_small_title_color'        => esc_html__( 'Title Color', 'helena-pro' ),
				'header_highlight_small_title_hover_color'  => esc_html__( 'Title Hover Color', 'helena-pro' ),
				'header_highlight_small_meta_color'         => esc_html__( 'Meta Color', 'helena-pro' ),
				'header_highlight_small_meta_hover_color'   => esc_html__( 'Meta Hover Color', 'helena-pro' ),
			);
			break;

		case 'slider_color':
			$options = array(
				'slider_background_color'              => esc_html__( 'Background Color', 'helena-pro' ),
				'slider_content_wrapper_background_color'              => esc_html__( 'Content Wrapper Background Color', 'helena-pro' ),
				'slider_title_color'                    => esc_html__( 'Title Color', 'helena-pro' ),
				'slider_title_hover_color'                    => esc_html__( 'Title Hover Color', 'helena-pro' ),
				'slider_text_color'                    => esc_html__( 'Text Color', 'helena-pro' ),
				'slider_link_color'                    => esc_html__( 'Link Color', 'helena-pro' ),
				'slider_link_hover_color'              => esc_html__( 'Link Hover Color', 'helena-pro' ),
				'slider_button_background_color'       => esc_html__( 'Button Background Color', 'helena-pro' ),
				'slider_button_text_color'             => esc_html__( 'Button Text Color', 'helena-pro' ),
				'slider_button_border_color'           => esc_html__( 'Button Border Color', 'helena-pro' ),
				'slider_button_hover_background_color' => esc_html__( 'Button Hover Background Color', 'helena-pro' ),
				'slider_button_hover_text_color'       => esc_html__( 'Button Hover Text Color', 'helena-pro' ),
				'slider_button_hover_border_color'     => esc_html__( 'Button Hover Border Color', 'helena-pro' ),
				);
			break;

		case 'hero_content_color':
			$options = array(
				'hero_content_background_color'  => esc_html__( 'Background Color', 'helena-pro' ),
				'hero_content_text_color'        => esc_html__( 'Text Color', 'helena-pro' ),
				'hero_content_title_color'       => esc_html__( 'Title Color', 'helena-pro' ),
				'hero_content_title_hover_color' => esc_html__( 'Title Hover Color', 'helena-pro' ),
				'hero_content_link_color'        => esc_html__( 'Link Color', 'helena-pro' ),
				'hero_content_link_hover_color'  => esc_html__( 'Link Hover Color', 'helena-pro' ),
			);
			break;

		case 'featured_content_color':
			$options = array(
				'featured_content_background_color'   => esc_html__( 'Background Color', 'helena-pro' ),
				'featured_content_headline_color'     => esc_html__( 'Headline Color', 'helena-pro' ),
				'featured_content_sub_headline_color' => esc_html__( 'Sub Headline Color', 'helena-pro' ),
				'featured_content_title_color'        => esc_html__( 'Title Color', 'helena-pro' ),
				'featured_content_title_hover_color'  => esc_html__( 'Title Hover Color', 'helena-pro' ),
				'featured_content_text_color'         => esc_html__( 'Text Color', 'helena-pro' ),
				'featured_content_link_color'         => esc_html__( 'Link Color', 'helena-pro' ),
				'featured_content_link_hover_color'   => esc_html__( 'Link Hover Color', 'helena-pro' ),
			);
			break;

		case 'menu_color':
			$options = array(
				'menu_background_color'              => esc_html__( 'Menu Background color', 'helena-pro' ),
				'menu_color'                         => esc_html__( 'Menu Color', 'helena-pro' ),
				'menu_hover_active_background_color' => esc_html__( 'Hover Active Background Color', 'helena-pro' ),
				'menu_hover_active_text_color'       => esc_html__( 'Hover Active Text Color', 'helena-pro' ),
				'sub_menu_background_color'          => esc_html__( 'Sub Menu Background Color', 'helena-pro' ),
				'sub_menu_border_color'              => esc_html__( 'Sub Menu Border Color', 'helena-pro' ),
				'sub_menu_text_color'                => esc_html__( 'Sub Menu Text Color', 'helena-pro' ),
				'sub_menu_hover_background_color'    => esc_html__( 'Sub Menu Hover Background Color', 'helena-pro' ),
				'sub_menu_hover_border_color'        => esc_html__( 'Sub Menu Hover Border Color', 'helena-pro' ),
				'sub_menu_hover_text_color'          => esc_html__( 'Sub Menu Hover Color', 'helena-pro' ),
			);
			break;

		case 'mobile_menu_color':
			$options = array(
				'mobile_menu_button_background_color' => esc_html__( 'Button Background Color', 'helena-pro' ),
				'mobile_menu_button_border_color' => esc_html__( 'Button Border Color', 'helena-pro' ),
				'mobile_menu_button_text_color' => esc_html__( 'Button Text Color', 'helena-pro' ),
				'mobile_menu_hover_button_background_color' => esc_html__( 'Hover Button Background Color', 'helena-pro' ),
				'mobile_menu_hover_button_border_color' => esc_html__( 'Hover Button Border Color', 'helena-pro' ),
				'mobile_menu_hover_button_text_color' => esc_html__( 'Hover Button Text Color', 'helena-pro' ),
				'mobile_menu_focus_button_background_color' => esc_html__( 'Focus Button Background Color', 'helena-pro' ),
				'mobile_menu_focus_button_border_color' => esc_html__( 'Focus Button Border Color', 'helena-pro' ),
				'mobile_menu_focus_button_text_color' => esc_html__( 'Focus Button Text Color', 'helena-pro' ),
				'mobile_menu_dropdown_toggle_background_color' => esc_html__( 'Dropdown Toggle Background Color', 'helena-pro' ),
				'mobile_menu_dropdown_toggle_color' => esc_html__( 'Dropdown Toggle Color', 'helena-pro' ),
				'mobile_menu_dropdown_toggle_background_hover_color' => esc_html__( 'Dropdown Toggle Background Hover Color', 'helena-pro' ),
				'mobile_menu_dropdown_toggle_hover_color' => esc_html__( 'Dropdown Toggle Hover Color', 'helena-pro' ),
			);
			break;
	}

	return $options;
}
add_filter( 'helena_color_options', 'helena_get_color_options' );

/**
 * Returns an array of comment options for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_comment_options() {
	$options = array(
		'use-wordpress-setting' => esc_html__( 'Use WordPress Setting', 'helena-pro' ),
		'disable-in-pages'      => esc_html__( 'Disable in Pages', 'helena-pro' ),
		'disable-completely'    => esc_html__( 'Disable Completely', 'helena-pro' ),
	);

	return apply_filters( 'helena_comment_options', $options );
}

/**
 * Returns an array of layout options registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_layouts() {
	$options = array(
			'left-sidebar'          => esc_html__( 'Primary Sidebar, Content', 'helena-pro' ),
			'right-sidebar'         => esc_html__( 'Content, Primary Sidebar', 'helena-pro' ),
			'no-sidebar'            => esc_html__( 'No Sidebar ( Content Width )', 'helena-pro' ),
			'no-sidebar-full-width' => esc_html__( 'No Sidebar ( Full Width )', 'helena-pro' ),
			'no-sidebar-one-column' => esc_html__( 'No Sidebar ( One Column )', 'helena-pro' ),
		);
	return apply_filters( 'helena_layouts', $options );
}

/**
 * Returns an array of pagination schemes registered for helena.
 *
 * @since Helena Pro 1.0
 */
function helena_get_pagination_types() {
	$options = array(
		'default'                => esc_html__( 'Default(Older Posts/Newer Posts)', 'helena-pro' ),
		'numeric'                => esc_html__( 'Numeric', 'helena-pro' ),
		'infinite-scroll-click'  => esc_html__( 'Infinite Scroll (Click)', 'helena-pro' ),
		'infinite-scroll-scroll' => esc_html__( 'Infinite Scroll (Scroll)', 'helena-pro' ),
	);

	return apply_filters( 'helena_get_pagination_types', $options );
}

/**
 * Returns an array of avaliable fonts registered for helena
 *
 * @since Helena Pro 1.0
 */
function helena_avaliable_fonts() {
	$avaliable_fonts = array(
		'arial-black' => array(
			'value' => 'arial-black',
			'label' => '"Arial Black", Gadget, sans-serif',
		),
		'allan' => array(
			'value' => 'allan',
			'label' => '"Allan", sans-serif',
		),
		'allerta' => array(
			'value' => 'allerta',
			'label' => '"Allerta", sans-serif',
		),
		'amaranth' => array(
			'value' => 'amaranth',
			'label' => '"Amaranth", sans-serif',
		),
		'arial' => array(
			'value' => 'arial',
			'label' => 'Arial, Helvetica, sans-serif',
		),
		'bitter' => array(
			'value' => 'bitter',
			'label' => '"Bitter", sans-serif',
		),
		'cabin' => array(
			'value' => 'cabin',
			'label' => '"Cabin", sans-serif',
		),
		'cantarell' => array(
			'value' => 'cantarell',
			'label' => '"Cantarell", sans-serif',
		),
		'century-gothic' => array(
			'value' => 'century-gothic',
			'label' => '"Century Gothic", sans-serif',
		),
		'courier-new' => array(
			'value' => 'courier-new',
			'label' => '"Courier New", Courier, monospace',
		),
		'crimson-text' => array(
			'value' => 'crimson-text',
			'label' => '"Crimson Text", sans-serif',
		),
		'cuprum' => array(
			'value' => 'cuprum',
			'label' => '"Cuprum", sans-serif',
		),
		'dancing-script' => array(
			'value' => 'dancing-script',
			'label' => '"Dancing Script", sans-serif',
		),
		'droid-sans' => array(
			'value' => 'droid-sans',
			'label' => '"Droid Sans", sans-serif',
		),
		'droid-serif' => array(
			'value' => 'droid-serif',
			'label' => '"Droid Serif", sans-serif',
		),
		'exo' => array(
			'value' => 'exo',
			'label' => '"Exo", sans-serif',
		),
		'exo-2' => array(
			'value' => 'exo-2',
			'label' => '"Exo 2", sans-serif',
		),
		'georgia' => array(
			'value' => 'georgia',
			'label' => 'Georgia, "Times New Roman", Times, serif',
		),
		'helvetica' => array(
			'value' => 'helvetica',
			'label' => 'Helvetica, "Helvetica Neue", Arial, sans-serif',
		),
		'helvetica-neue' => array(
			'value' => 'helvetica-neue',
			'label' => '"Helvetica Neue",Helvetica,Arial,sans-serif',
		),
		'istok-web' => array(
			'value' => 'istok-web',
			'label' => '"Istok Web", sans-serif',
		),
		'impact' => array(
			'value' => 'impact',
			'label' => 'Impact, Charcoal, sans-serif',
		),
		'josefin-sans' => array(
			'value' => 'josefin-sans',
			'label' => '"Josefin Sans", sans-serif',
		),
		'lato' => array(
			'value' => 'lato',
			'label' => '"Lato", sans-serif',
		),
		'lucida-sans-unicode' => array(
			'value' => 'lucida-sans-unicode',
			'label' => '"Lucida Sans Unicode", "Lucida Grande", sans-serif',
		),
		'lucida-grande' => array(
			'value' => 'lucida-grande',
			'label' => '"Lucida Grande", "Lucida Sans Unicode", sans-serif',
		),
		'lobster' => array(
			'value' => 'lobster',
			'label' => '"Lobster", sans-serif',
		),
		'lora' => array(
			'value' => 'lora',
			'label' => '"Lora", serif',
		),
		'monaco' => array(
			'value' => 'monaco',
			'label' => 'Monaco, Consolas, "Lucida Console", monospace, sans-serif',
		),
		'montserrat' => array(
			'value' => 'montserrat',
			'label' => '"Montserrat", sans-serif',
		),
		'nobile' => array(
			'value' => 'nobile',
			'label' => '"Nobile", sans-serif',
		),
		'noto-serif' => array(
			'value' => 'noto-serif',
			'label' => '"Noto Serif", serif',
		),
		'neuton' => array(
			'value' => 'neuton',
			'label' => '"Neuton", serif',
		),
		'open-sans' => array(
			'value' => 'open-sans',
			'label' => '"Open Sans", sans-serif',
		),
		'oswald' => array(
			'value' => 'oswald',
			'label' => '"Oswald", sans-serif',
		),
		'palatino' => array(
			'value' => 'palatino',
			'label' => 'Palatino, "Palatino Linotype", "Book Antiqua", serif',
		),
		'patua-one' => array(
			'value' => 'patua-one',
			'label' => '"Patua One", sans-serif',
		),
		'playfair-display' => array(
			'value' => 'playfair-display',
			'label' => '"Playfair Display", sans-serif',
		),
		'pt-sans' => array(
			'value' => 'pt-sans',
			'label' => '"PT Sans", sans-serif',
		),
		'pt-serif' => array(
			'value' => 'pt-serif',
			'label' => '"PT Serif", serif',
		),
		'quattrocento-sans' => array(
			'value' => 'quattrocento-sans',
			'label' => '"Quattrocento Sans", sans-serif',
		),
		'roboto' => array(
			'value' => 'roboto',
			'label' => '"Roboto", sans-serif',
		),
		'roboto-slab' => array(
			'value' => 'roboto-slab',
			'label' => '"Roboto Slab", serif',
		),
		'rubik' => array(
			'value' => 'rubik',
			'label' => '"Rubik", serif',
		),
		'sans-serif' => array(
			'value' => 'sans-serif',
			'label' => 'Sans Serif, Arial',
		),
		'source-sans-pro' => array(
			'value' => 'source-sans-pro',
			'label' => '"Source Sans Pro", sans-serif',
		),
		'tahoma' => array(
			'value' => 'tahoma',
			'label' => 'Tahoma, Geneva, sans-serif',
		),
		'trebuchet-ms' => array(
			'value' => 'trebuchet-ms',
			'label' => '"Trebuchet MS", "Helvetica", sans-serif',
		),
		'times-new-roman' => array(
			'value' => 'times-new-roman',
			'label' => '"Times New Roman", Times, serif',
		),
		'ubuntu' => array(
			'value' => 'ubuntu',
			'label' => '"Ubuntu", sans-serif',
		),
		'varela' => array(
			'value' => 'varela',
			'label' => '"Varela", sans-serif',
		),
		'verdana' => array(
			'value' => 'verdana',
			'label' => 'Verdana, Geneva, sans-serif',
		),
		'yanone-kaffeesatz' => array(
			'value' => 'yanone-kaffeesatz',
			'label' => '"Yanone Kaffeesatz", sans-serif',
		)
	);

	return apply_filters( 'helena_avaliable_fonts', $avaliable_fonts );
}

/**
 * Returns an array of content layout options registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_get_archive_content_layout() {
	$options = array(
		'excerpt-image-top'   => esc_html__( 'Show Excerpt (Image Top)', 'helena-pro' ),
		'excerpt-image-left'  => esc_html__( 'Show Excerpt (Image Left)', 'helena-pro' ),
		'excerpt-image-right' => esc_html__( 'Show Excerpt (Image Right)', 'helena-pro' ),
		'full-content'        => esc_html__( 'Show Full Content (No Featured Image)', 'helena-pro' )
	);
	return apply_filters( 'helena_get_archive_content_layout', $options );
}

/**
 * Returns an array of content featured image size.
 *
 * @since Helena Pro 1.0
 */
function helena_single_post_image_layout_options() {
	$options['disabled'] 	= esc_html__( 'Disabled', 'helena-pro' );
	$options['full']     	= esc_html__( 'Full size', 'helena-pro' );
	$options['helena-slider']	= esc_html__( 'Slider size (1170x658)', 'helena-pro' );

	return apply_filters( 'helena_single_post_image_layout_options', $options );
}

/**
 * Returns an array of content and slider layout options registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_featured_section_enable_options() {
	$options = array(
		'homepage'    => esc_html__( 'Homepage / Frontpage', 'helena-pro' ),
		'entire-site' => esc_html__( 'Entire Site', 'helena-pro' ),
		'disabled'    => esc_html__( 'Disabled', 'helena-pro' ),
	);

	return apply_filters( 'helena_featured_section_enable_options', $options );
}

/**
 * Returns an array of header highlight content types registered for Helena.
 *
 * @since Helena Pro 1.0
 */
function helena_header_highlight_content_types() {
	$options = array(
		'demo-header-highlight-content'     => esc_html__( 'Demo Content', 'helena-pro' ),
		'header-highlight-post-content'     => esc_html__( 'Post Content', 'helena-pro' ),
		'header-highlight-page-content'     => esc_html__( 'Page Content', 'helena-pro' ),
		'header-highlight-category-content' => esc_html__( 'Category Content', 'helena-pro' ),
		'header-highlight-image-content'    => esc_html__( 'Image Content', 'helena-pro' ),
		'header-highlight-embed-content'    => esc_html__( 'Embed Content', 'helena-pro' ),
	);

	return apply_filters( 'helena_header_highlight_content_types', $options );
}

/**
 * Returns an array of featured content show registered for parallaxframe.
 *
 * @since parallaxframe 1.6
 */
function helena_featured_content_show() {
	$options = array(
		'excerpt'      => esc_html__( 'Show Excerpt', 'helena-pro' ),
		'full-content' => esc_html__( 'Show Full Content', 'helena-pro' ),
		'hide-content' => esc_html__( 'Hide Content', 'helena-pro' )
	);

	return apply_filters( 'helena_featured_content_show', $options );
}

/**
 * Returns an array of feature slider transition effects
 *
 * @since Helena Pro 1.0
 */
function helena_featured_slider_transition_effects() {
	$options = array(
		'fade' 		=> esc_html__( 'Fade', 'helena-pro' ),
		'fadeout' 	=> esc_html__( 'Fade Out', 'helena-pro' ),
		'none' 		=> esc_html__( 'None', 'helena-pro' ),
		'scrollHorz'=> esc_html__( 'Scroll Horizontal', 'helena-pro' ),
		'scrollVert'=> esc_html__( 'Scroll Vertical', 'helena-pro' ),
		'flipHorz'	=> esc_html__( 'Flip Horizontal', 'helena-pro' ),
		'flipVert'	=> esc_html__( 'Flip Vertical', 'helena-pro' ),
		'tileSlide'	=> esc_html__( 'Tile Slide', 'helena-pro' ),
		'tileBlind'	=> esc_html__( 'Tile Blind', 'helena-pro' ),
		'shuffle'	=> esc_html__( 'Shuffle', 'helena-pro' )
	);

	return apply_filters( 'helena_featured_slider_transition_effects', $options );
}

/**
 * Returns an array of feature slider types registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_featured_slider_types() {
	$options = array(
		'demo-featured-slider'     => esc_html__( 'Demo Featured Slider', 'helena-pro' ),
		'featured-post-slider'     => esc_html__( 'Featured Post Slider', 'helena-pro' ),
		'featured-page-slider'     => esc_html__( 'Featured Page Slider', 'helena-pro' ),
		'featured-category-slider' => esc_html__( 'Featured Category Slider', 'helena-pro' ),
		'featured-image-slider'    => esc_html__( 'Featured Image Slider', 'helena-pro' )
	);

	return apply_filters( 'helena_featured_slider_types', $options );
}

/**
 * Returns an array of featured slider image loader options
 *
 * @since Helena Pro 1.0
 */
function helena_featured_slider_image_loader() {
	$options = array(
		'true'  => esc_html__( 'True', 'helena-pro' ),
		'wait'  => esc_html__( 'Wait', 'helena-pro' ),
		'false' => esc_html__( 'False', 'helena-pro' )
	);

	return apply_filters( 'helena_featured_slider_image_loader', $options );
}

/**
 * Returns an array of portfolio types registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_portfolio_types() {
	$options = array(
		'demo-portfolio'     => esc_html__( 'Demo Portfolio', 'helena-pro' ),
		'post-portfolio'     => esc_html__( 'Post Portfolio', 'helena-pro' ),
		'page-portfolio'     => esc_html__( 'Page Portfolio', 'helena-pro' ),
		'category-portfolio' => esc_html__( 'Category Portfolio', 'helena-pro' ),
		'image-portfolio'    => esc_html__( 'Image Portfolio', 'helena-pro' )
	);

	return apply_filters( 'helena_portfolio_types', $options );
}


/**
 * Returns an array of feature content types registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_logo_slider_types() {
	$options = array(
		'demo' => esc_html__( 'Demo Logo Slider', 'helena-pro' ),
		'post' => esc_html__( 'Post Logo Slider', 'helena-pro' ),
		'page' => esc_html__( 'Page Logo Slider', 'helena-pro' ),
		'category' => esc_html__( 'Category Logo Slider', 'helena-pro' ),
		'image' => esc_html__( 'Image Logo Slider', 'helena-pro' )
	);

	return apply_filters( 'helena_logo_slider_types', $options );
}

/**
 * Returns an array of hero content types registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_hero_content_types() {
	$options = array(
		'demo-hero-content' => esc_html__( 'Demo Content', 'helena-pro' ),
		'hero-post-content' => esc_html__( 'Post Content', 'helena-pro' ),
		'hero-page-content' => esc_html__( 'Page Content', 'helena-pro' ),
		'hero-category-content' => esc_html__( 'Category Content', 'helena-pro' ),
		'hero-custom-content' => esc_html__( 'Custom Content', 'helena-pro' )
	);

	return apply_filters( 'helena_hero_content_types', $options );
}

/**
 * Returns an array of featured content options registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_featured_content_layout_options() {
	$options = array(
		'one-column'	=> esc_html__( '1 Column', 'helena-pro' ),
		'two-columns'	=> esc_html__( '2 Columns', 'helena-pro' ),
		'three-columns'	=> esc_html__( '3 Columns', 'helena-pro' ),
		'four-columns'	=> esc_html__( '4 Columns', 'helena-pro' )
	);

	return apply_filters( 'helena_featured_content_layout_options', $options );
}

/**
 * Returns an array of metabox layout options registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_metabox_layouts() {
	$options = array(
		'default' 	=> array(
			'id' 	=> 'helena-layout-option',
			'value' => 'default',
			'label' => esc_html__( 'Default', 'helena-pro' ),
		),
		'left-sidebar' 	=> array(
			'id' 	=> 'helena-layout-option',
			'value' => 'left-sidebar',
			'label' => esc_html__( 'Primary Sidebar, Content', 'helena-pro' ),
		),
		'right-sidebar' => array(
			'id' 	=> 'helena-layout-option',
			'value' => 'right-sidebar',
			'label' => esc_html__( 'Content, Primary Sidebar', 'helena-pro' ),
		),
		'no-sidebar'	=> array(
			'id' 	=> 'helena-layout-option',
			'value' => 'no-sidebar',
			'label' => esc_html__( 'No Sidebar ( Content Width )', 'helena-pro' ),
		),
		'no-sidebar-full-width' => array(
			'id' 	=> 'helena-layout-option',
			'value' => 'no-sidebar-full-width',
			'label' => esc_html__( 'No Sidebar ( Full Width )', 'helena-pro' ),
		),
		'no-sidebar-one-column' => array(
			'id' 	=> 'helena-layout-option',
			'value' => 'no-sidebar-one-column',
			'label' => esc_html__( 'No Sidebar ( One Column )', 'helena-pro' ),
		),
	);
	return apply_filters( 'helena_layouts', $options );
}

/**
 * Returns an array of metabox header featured image options registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_metabox_header_featured_image_options() {
	$options = array(
		'default' => array(
			'id'		=> 'helena-header-image',
			'value' 	=> 'default',
			'label' 	=> esc_html__( 'Default', 'helena-pro' ),
		),
		'enable' => array(
			'id'		=> 'helena-header-image',
			'value' 	=> 'enable',
			'label' 	=> esc_html__( 'Enable', 'helena-pro' ),
		),
		'disable' => array(
			'id'		=> 'helena-header-image',
			'value' 	=> 'disable',
			'label' 	=> esc_html__( 'Disable', 'helena-pro' )
		)
	);
	return apply_filters( 'header_featured_image_options', $options );
}


/**
 * Returns an array of metabox sidebar options registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_metabox_sidebar_options() {
	$options = array(
		'main-sidebar' => array(
			'id'		=> 'helena-sidebar-options',
			'value' 	=> 'default-sidebar',
			'label' 	=> esc_html__( 'Default Sidebar', 'helena-pro' )
		),
		'optional-sidebar-one' => array(
			'id' 	=> 'helena-sidebar-options',
			'value' => 'optional-sidebar-one',
			'label' => esc_html__( 'Optional Sidebar One', 'helena-pro' )
		),
		'optional-sidebar-two' => array(
			'id' 	=> 'helena-sidebar-options',
			'value' => 'optional-sidebar-two',
			'label' => esc_html__( 'Optional Sidebar Two', 'helena-pro' )
		),
		'optional-sidebar-three' => array(
			'id' 	=> 'helena-sidebar-options',
			'value' => 'optional-sidebar-three',
			'label' => esc_html__( 'Optional Sidebar three', 'helena-pro' )
		)
	);
	return apply_filters( 'sidebar_options', $options );
}


/**
 * Returns an array of metabox featured image options registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_metabox_featured_image_options() {
	$options['default'] = array(
		'id'	=> 'helena-featured-image',
		'value' => 'default',
		'label' => esc_html__( 'Default', 'helena-pro' ),
	);

	$options['disabled'] = array(
		'id' 	=> 'helena-featured-image',
		'value' => 'disabled',
		'label' => esc_html__( 'Disabled', 'helena-pro' )
	);

	$options['full'] = array(
		'id'	=> 'helena-featured-image',
		'value'	=> 'full',
		'label' => esc_html__( 'Full Image', 'helena-pro' ),
	);

	$options['helena-slider'] = array(
		'id'	=> 'helena-featured-image',
		'value'	=> 'helena-slider',
		'label' => esc_html__( 'Slider size (1170x658)', 'helena-pro' ),
	);

	return apply_filters( 'helena_metabox_featured_image_options', $options );
}

/**
 * Returns an array of feature content types registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_featured_content_types() {
	$options = array(
		'demo-featured-content'     => esc_html__( 'Demo Featured Content', 'helena-pro' ),
		'featured-post-content'     => esc_html__( 'Featured Post Content', 'helena-pro' ),
		'featured-page-content'     => esc_html__( 'Featured Page Content', 'helena-pro' ),
		'featured-category-content' => esc_html__( 'Featured Category Content', 'helena-pro' ),
		'featured-image-content'    => esc_html__( 'Featured Image Content', 'helena-pro' )
	);

	return apply_filters( 'helena_featured_content_types', $options );
}

/**
 * Returns an array of featured content background image positions
 *
 * @since Halena Pro 1.0
 */
function helena_featured_content_background_display_positions() {
	$options = array(
		'top'    => esc_html__( 'Top', 'helena-pro' ),
		'bottom' => esc_html__( 'Bottom', 'helena-pro' )
	);
	return apply_filters( 'helena_featured_content_background_display_positions', $options );
}


/**
 * Returns an array of featured content background repeat options
 *
 * @since Halena Pro 1.0
 */
function helena_featured_content_background_repeat_options() {
	$options = array(
		'no-repeat' => esc_html__( 'No repeat', 'helena-pro' ),
		'tile'      => esc_html__( 'Tile', 'helena-pro' )
	);

	return apply_filters( 'helena_featured_content_background_repeat_options', $options );
}


/**
 * Returns an array of featured content background attachment options
 *
 * @since Halena Pro 1.0
 */
function helena_featured_content_background_attachment_options() {
	$options = array(
		'scroll' => esc_html__( 'Scroll', 'helena-pro' ),
		'fixed'  => esc_html__( 'Fixed', 'helena-pro' )
	);

	return apply_filters( 'helena_featured_content_background_attachment_options', $options );
}

/**
 * Returns an array of hero content types registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_promotion_headline_types() {
	$options = array(
		'demo'     => esc_html__( 'Demo Promotion Headline', 'helena-pro' ),
		'post'     => esc_html__( 'Post Promotion Headline', 'helena-pro' ),
		'page'     => esc_html__( 'Page Promotion Headline', 'helena-pro' ),
		'category' => esc_html__( 'Category Promotion Headline', 'helena-pro' ),
		'custom'   => esc_html__( 'Custom Promotion Headline', 'helena-pro' )
	);

	return apply_filters( 'helena_promotion_headline_types', $options );
}

/**
 * Returns an array of hero content types registered for parallaxframe.
 *
 * @since Helena Pro 1.0
 */
function helena_get_category_list() {
	$cats    = get_categories();

	foreach ( $cats as $cat ) {
		$options[$cat->term_id] = $cat->name;
	}

	return apply_filters( 'helena_get_category_list', $options );
}

/**
 * Returns the default options for parallaxframe dark theme.
 *
 * @since parallaxframe 1.0
 */
function helena_default_dark_color_options() {
	$default_dark_color_options = array(
		//Basic Color Options
		'background_color'                                   => '#262626',
		'text_color'                                         => '#e5e5e5',
		'link_color'                                         => '#e8554e',
		'link_hover_color'                                   => '#e5e5e5',

		//Header Color Options
		'header_textcolor'                                   => '#ffffff',
		'header_background_color'                            => '#000000',
		'site_title_hover_color'                             => '#e8554e',
		'tagline_color'                                      => '#dddddd',

		// Header Image Color Options
		'header_image_background_color'                      => '#000000',
		'header_image_text_color'                            => '#ffffff',
		'header_image_content_wrapper_background_color'      => '#666666',
		'header_image_link_color'                            => '#e8554e',
		'header_image_link_hover_color'                      => '#ffffff',
		'header_image_title_color'                           => '#ffffff',
		'header_image_title_hover_color'                     => '#e8554e',
		'header_image_button_background_color'               => '',
		'header_image_button_border_color'                   => '#ffffff',
		'header_image_button_text_color'                     => '#ffffff',
		'header_image_button_hover_background_color'         => '#e8554e',
		'header_image_button_hover_border_color'             => '#e8554e',
		'header_image_button_hover_text_color'               => '#ffffff',

		// Breadcrumb Color Options.
		'breadcrumb_background_color'                        => '#000000',
		'breadcrumb_text_color'                              => '#ffffff',
		'breadcrumb_link_color'                              => '#e8554e',
		'breadcrumb_link_hover_color'                        => '#ffffff',

		// Content Color Options
		'content_wrapper_background_color'                   => '#1a1a1a',
		'content_background_color'                           => '',
		'alternate_post_background_color'                    => '#111111',
		'content_title_color'                                => '#ffffff',
		'content_title_hover_color'                          => '#e8554e',
		'content_meta_color'                                 => '#e5e5e5',
		'content_meta_hover_color'                           => '#e8554e',

		//Social Menu Color Options
		'social_menu_color'                                  => '#e5e5e5',
		'social_menu_border_color'                           => '#e5e5e5',
		'social_menu_hover_color'                            => '#e8554e',
		'social_menu_hover_border_color'                     => '#e8554e',
		'social_menu_brand_color'                            => 'disable',

		//Sidebar Color Options
		'sidebar_background_color'                           => '',
		'sidebar_widget_title_color'                         => '#ffffff',
		'sidebar_widget_text_color'                          => '#e5e5e5',
		'sidebar_widget_link_color'                          => '#ffffff',
		'sidebar_widget_link_hover_color'                    => '#e8554e',

		//Pagination Color Options
		'pagination_background_color'                        => '#000000',
		'pagination_link_color'                              => '#ffffff',
		'pagination_text_color'                              => '#e5e5e5',
		'pagination_hover_background_color'                  => '#e8554e',
		'pagination_hover_link_color'                        => '#ffffff',

		//Footer Color Options
		'footer_background_color'                            => '',
		'footer_text_color'                                  => '#e5e5e5',
		'footer_link_color'                                  => '#ffffff',
		'footer_link_hover_color'                            => '#e8554e',
		'footer_sidebar_area_background_color'               => '#000000',
		'footer_widget_title_color'                          => '#ffffff',
		'footer_widget_text_color'                           => '#bbbbbb',
		'footer_widget_link_color'                           => '#dddddd',
		'footer_widget_link_hover_color'                     => '#e8554e',

		//Promotion Headline Color Options
		'promotion_headline_background_color'                => '#ffffff',
		'promotion_headline_text_color'                      => '#666666',
		'promotion_headline_link_color'                      => '#e8554e',
		'promotion_headline_link_hover_color'                => '#666666',
		'promotion_headline_button_background_color'         => '',
		'promotion_headline_button_link_color'               => '#666666',
		'promotion_headline_button_border_color'             => '#666666',
		'promotion_headline_button_hover_background_color'   => '#e8554e',
		'promotion_headline_button_hover_link_color'         => '#ffffff',
		'promotion_headline_button_hover_border_color'       => '#e8554e',

		//Scrollup Color Options
		'scrollup_background_color'                          => '',
		'scrollup_text_color'                                => '#666666',
		'scrollup_border_color'                              => '#666666',
		'scrollup_hover_background_color'                    => '',
		'scrollup_hover_text_color'                          => '#e5e5e5',
		'scrollup_hover_border_color'                        => '#e5e5e5',

		//Header Highlight Content Color Options
		'header_highlight_background_color'                  => '#ffffff',
		'header_highlight_title_color'                       => '#ffffff',
		'header_highlight_title_hover_color'                 => '#e8554e',
		'header_highlight_text_color'                        => '#666666',
		'header_highlight_headline_color'                    => '#000000',
		'header_highlight_headline_hover_color'              => '#e8554e',
		'header_highlight_content_background_color'          => '#ffffff',
		'header_highlight_link_color'                        => '#e8554e',
		'header_highlight_link_hover_color'                  => '#666666',
		'header_highlight_meta_color'                        => '#ffffff',
		'header_highlight_meta_hover_color'                  => '#e8554e',
		'header_highlight_small_title_color'                 => '#ffffff',
		'header_highlight_small_title_hover_color'           => '#e8554e',
		'header_highlight_small_meta_color'                  => '#e5e5e5',
		'header_highlight_small_meta_hover_color'            => '#e8554e',

		//Slider Color Options
		'slider_background_color'                            => '#000000',
		'slider_text_color'                                  => '#ffffff',
		'slider_content_wrapper_background_color'            => '#666666',
		'slider_link_color'                                  => '#e8554e',
		'slider_link_hover_color'                            => '#ffffff',
		'slider_title_color'                                 => '#ffffff',
		'slider_title_hover_color'                           => '#e8554e',
		'slider_button_background_color'                     => '',
		'slider_button_text_color'                           => '#ffffff',
		'slider_button_border_color'                         => '#ffffff',
		'slider_button_hover_background_color'               => '#e8554e',
		'slider_button_hover_text_color'                     => '#ffffff',
		'slider_button_hover_border_color'                   => '#e8554e',

		//Hero Conent Color Options
		'hero_content_background_color'                      => '#ffffff',
		'hero_content_title_color'                           => '#000000',
		'hero_content_title_hover_color'                     => '#e8554e',
		'hero_content_text_color'                            => '#666666',
		'hero_content_link_color'                            => '#e8554e',
		'hero_content_link_hover_color'                      => '#666666',

		//Featured Content Color Options
		'featured_content_background_color'                  => '#ffffff',
		'featured_content_text_color'                        => '#ffffff',
		'featured_content_headline_color'                    => '#000000',
		'featured_content_sub_headline_color'                => '#666666',
		'featured_content_title_color'                       => '#000000',
		'featured_content_title_hover_color'                 => '#e8554e',
		'featured_content_link_color'                        => '#e8554e',
		'featured_content_link_hover_color'                  => '#666666',

		//Primary Menu Color Options
		'menu_background_color'                              => '',
		'menu_color'                                         => '#ffffff',
		'menu_hover_active_background_color'                 => '',
		'menu_hover_active_text_color'                       => '#e8554e',
		'sub_menu_background_color'                          => '#ffffff',
		'sub_menu_border_color'                              => '#d1d1d1',
		'sub_menu_text_color'                                => '#242424',
		'sub_menu_hover_background_color'                    => '#ffffff',
		'sub_menu_hover_border_color'                        => '#d1d1d1',
		'sub_menu_hover_text_color'                          => '#e8554e',

		// Mobile Menu
		'mobile_menu_button_background_color'                => '',
		'mobile_menu_button_border_color'                    => '#d1d1d1',
		'mobile_menu_button_text_color'                      => '#ffffff',
		'mobile_menu_hover_button_background_color'          => '',
		'mobile_menu_hover_button_border_color'              => '#e8554e',
		'mobile_menu_hover_button_text_color'                => '#e8554e',
		'mobile_menu_focus_button_background_color'          => '#1a1a1a',
		'mobile_menu_focus_button_border_color'              => '#1a1a1a',
		'mobile_menu_focus_button_text_color'                => '#e8554e',
		'mobile_menu_dropdown_toggle_background_color'       => '',
		'mobile_menu_dropdown_toggle_color'                  => '#ffffff',
		'mobile_menu_dropdown_toggle_background_hover_color' => '',
		'mobile_menu_dropdown_toggle_hover_color'            => '#e8554e',
	);

	return apply_filters( 'helena_default_dark_color_options', $default_dark_color_options );
}


/**
 * Checks if there are options already present from Helena free version and adds it to the Helena Pro theme options
 *
 * @since Helena Pro 1.0
 * @hook after_theme_switch
 */
function helena_setup_options() {
	//Perform action only if theme_mods_theme_mods_catchbase-pro does not exist
	if ( !get_option( 'theme_mods_helena-pro' ) ) {
		//Perform action only if theme_mods_catchbase free version exists
		if ( $helena_free_options = get_option ( 'theme_mods_helena' ) ) {
			update_option('theme_mods_helena-pro', $helena_free_options );
		}
	}
}
add_action( 'after_switch_theme', 'helena_setup_options' );