<?php
/**
 * The template for displaying meta box in page/post
 *
 * This adds Layout Options, Select Sidebar, Header Freatured Image Options, Single Page/Post Image Layout
 * This is only for the design purpose and not used to save any content
 *
 * @package Catch Themes
 * @subpackage Helena Pro
 * @since Helena Pro 1.0
 */

/**
 * Class to Add, Render and save metabox options
 *
 * @since Helena Pro 1.0
 */
class helena_meta_box {
	private $meta_box;

	private $fields;

	/**
	* Constructor
	*
	* @since Helena Pro 1.0
	*
	* @access public
	*
	*/
	public function __construct( $meta_box_id, $meta_box_title, $post_type ) {

		$this->meta_box = array (
			'id'        => $meta_box_id,
			'title'     => $meta_box_title,
			'post_type' => $post_type,
		);

		$this->fields = array(
			'helena-layout-option',
			'helena-header-image',
			'helena-sidebar-options',
			'helena-featured-image',
		);


		// Add metaboxes
		add_action( 'add_meta_boxes', array( $this, 'add' ) );

		add_action( 'save_post', array( $this, 'save' ) );
   	}

	/**
	* Add Meta Box for multiple post types.
	*
	* @since @since Helena Pro 1.0
	*
	* @access public
	*/
	public function add($postType) {
		if ( in_array( $postType, $this->meta_box['post_type'] ) ) {
			add_meta_box( $this->meta_box['id'], $this->meta_box['title'], array( $this, 'show' ), $postType );
		}
	}

	/**
	* Renders metabox
	*
	* @since Helena Pro 1.0
	*
	* @access public
	*/
	public function show() {
		global $post;

		$layout_options			= helena_metabox_layouts();
		$sidebar_options		= helena_metabox_sidebar_options();
		$featured_image_options	= helena_metabox_featured_image_options();
		$header_image_options 	= helena_metabox_header_featured_image_options();


	    // Use nonce for verification
	    wp_nonce_field( basename( __FILE__ ), 'helena_custom_meta_box_nonce' );

	    // Begin the field table and loop  ?>
	    <div id="helena-ui-tabs" class="ui-tabs">
		    <ul class="helena-ui-tabs-nav" id="helena-ui-tabs-nav">
		    	<li><a href="#frag1"><?php esc_html_e( 'Layout Options', 'helena-pro' ); ?></a></li>
		    	<li><a href="#frag2"><?php esc_html_e( 'Select Sidebar', 'helena-pro' ); ?></a></li>
		    	<li><a href="#frag3"><?php esc_html_e( 'Header Featured Image Options', 'helena-pro' ); ?></a></li>
		    	<li><a href="#frag4"><?php esc_html_e( 'Single Page/Post Image', 'helena-pro' ); ?></a></li>
		    </ul>
		    <div id="frag1" class="catch_ad_tabhead">
		    	<table id="layout-options" class="form-table" width="100%">
		            <tbody>
		                <tr>
		                    <select name="helena-layout-option" id="custom_element_grid_class">
		      					<?php
			                    foreach ( $layout_options as $field ) {
			                        $metalayout = get_post_meta( $post->ID, 'helena-layout-option', true );
			                        if ( empty( $metalayout ) ){
			                            $metalayout='default';
			                        }
			                   	?>
			                   		<option value="<?php echo $field['value']; ?>" <?php selected( $metalayout, $field['value'] ); ?>><?php echo $field['label']; ?></option>
		    					<?php
		    					} // end foreach
			                    ?>
		                    </select>
		                </tr>
		            </tbody>
		        </table>
		    </div>

		    <div id="frag2" class="catch_ad_tabhead">
		    	<table id="sidebar-metabox" class="form-table" width="100%">
		            <tbody>
		                <tr>
		                    <?php
		                    foreach ( $sidebar_options as $field ) {

		                        $metasidebar = get_post_meta( $post->ID, $field['id'], true );

		                        if ( empty( $metasidebar ) ){
		                            $metasidebar='default-sidebar';
		                        }
		                    ?>
		                        <td style="vertical-align: top;">
		                            <label class="description">
		                                <input type="radio" name="<?php echo $field['id']; ?>" value="<?php echo $field['value']; ?>" <?php checked( $field['value'], $metasidebar ); ?>/>&nbsp;&nbsp;<?php echo $field['label']; ?>
		                            </label>
		                        </td>

		                    <?php
		                    } // end foreach
		                    ?>
		                </tr>
		            </tbody>
		        </table>
		    </div>

	    	<div id="frag3" class="catch_ad_tabhead">
		    	<table id="header-image-metabox" class="form-table" width="100%">
		            <tbody>
		                <tr>
		                    <?php
							 	$metaheader = get_post_meta( $post->ID, 'helena-header-image', true );

		                        if ( empty( $metaheader ) ){
		                            $metaheader='default';
		                        }
								?>

	                        <td width="20%">
	                        	<label class="description"><?php esc_html_e( 'Header Image Option', 'helena-pro' ) ?>
	                            </label>
	                        </td>

	                        <td>
	                            <select name="helena-header-image">
	                                <?php foreach ( $header_image_options as $field ) { ?>
	                                <option <?php selected( $field['value'], $metaheader ); ?> value="<?php echo $field['value'];?>"><?php echo $field['label']; ?></option>
	                              	<?php }//end foreach ?>
	                            </select>
	                        </td>
		                </tr>

		                <tr>
		                	<td>
		                		<label class="description"><?php esc_html_e( 'Title', 'helena-pro' ) ?>
	                            </label>
	                        </td>

	                        <td>
	                        	<?php
									$type  = 'text';
									$name  = 'helena-featured-header-title';
									$value = get_post_meta( $post->ID, $name, true );
	                			?>

                                <input  class= "widefat" type="<?php echo esc_attr( $type ); ?>" name="<?php echo esc_attr( $name ); ?>" value="<?php echo esc_attr( $value ); ?>"/>
		                	</td>
		                </tr>

						<tr>
		                	<td>
		                		<label class="description"><?php esc_html_e( 'Content', 'helena-pro' ) ?>
	                            </label>
	                        </td>

	                        <td>
	                        	<?php
									$name  = 'helena-featured-header-content';
									$value = get_post_meta( $post->ID, $name, true );
	                			?>

                                <textarea class= "widefat" rows="4" name="<?php echo esc_attr( $name ); ?>"><?php echo esc_textarea( $value ); ?></textarea>
		                	</td>
		                </tr>

		                <tr>
		                	<td>
		                		<label class="description"><?php esc_html_e( 'Button Text', 'helena-pro' ) ?>
	                            </label>
	                        </td>

	                        <td>
	                        	<?php
									$type  = 'text';
									$name  = 'helena-featured-header-button-text';
									$value = get_post_meta( $post->ID, $name, true );
	                			?>

                                <input class= "widefat" type="<?php echo esc_attr( $type ); ?>" name="<?php echo esc_attr( $name ); ?>" value="<?php echo esc_attr( $value ); ?>"/>
		                	</td>
		                </tr>

		                <tr>
		                	<td>
		                		<label class="description"><?php esc_html_e( 'Link', 'helena-pro' ) ?>
	                            </label>
	                        </td>

	                        <td>
	                        	<?php
									$type  = 'text';
									$name  = 'helena-featured-header-button-link';
									$value = get_post_meta( $post->ID, $name, true );
	                			?>

                                <input class= "widefat" type="<?php echo esc_attr( $type ); ?>" name="<?php echo esc_attr( $name ); ?>" value="<?php echo esc_attr( $value ); ?>"/>
		                	</td>
		                </tr>

		                <tr>
		                	<td colspan="2">
		                		<?php
									$type  = 'checkbox';
									$name  = 'helena-featured-header-button-target';
									$value = get_post_meta( $post->ID, $name, true );

								?>

                                <label>
                                	<input type="<?php echo esc_attr( $type ); ?>" name="<?php echo esc_attr( $name ); ?>" value="1" <?php checked( $value, true ); ?>/>
                                	<?php esc_html_e( 'Check to Open Link in New Window/Tab', 'helena-pro' ); ?>
	                            </label>


		                	</td>
		                </tr>
		            </tbody>
		        </table>
		    </div>

		    <div id="frag4" class="catch_ad_tabhead">
		    	<table id="featured-image-metabox" class="form-table" width="100%">
		            <tbody>
		                <tr>
		                     <select name="helena-featured-image" id="custom_element_grid_class">
			                     <?php
				                    foreach ( $featured_image_options as $field ) {
				                        $metaimage = get_post_meta( $post->ID, 'helena-featured-image', true );
				                        if ( empty( $metaimage ) ){
				                            $metaimage='default';
				                        }
				                   	?>
				                   		<option value="<?php echo $field['value']; ?>" <?php selected( $metaimage, $field['value'] ); ?>><?php echo $field['label']; ?></option>
			    					<?php
			    					} // end foreach
			                    ?>
			                </select>
		                </tr>
		            </tbody>
		        </table>
		    </div>
		</div>
	<?php
	}

	/**
	 * Save custom metabox data
	 *
	 * @action save_post
	 *
	 * @since Helena Pro 1.0
	 *
	 * @access public
	 */
	public function save( $post_id ) {
		global $post_type;

		$post_type_object = get_post_type_object( $post_type );

	    if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )                      // Check Autosave
	    || ( ! isset( $_POST['post_ID'] ) || $post_id != $_POST['post_ID'] )        // Check Revision
	    || ( ! in_array( $post_type, $this->meta_box['post_type'] ) )                  // Check if current post type is supported.
	    || ( ! check_admin_referer( basename( __FILE__ ), 'helena_custom_meta_box_nonce') )    // Check nonce - Security
	    || ( ! current_user_can( $post_type_object->cap->edit_post, $post_id ) ) )  // Check permission
	    {
	      return $post_id;
	    }

	    foreach ( $this->fields as $field ) {
			$old = get_post_meta( $post_id, $field, true);

			$new = $_POST[ $field ];

			delete_post_meta( $post_id, $field );

			if ( '' == $new || array() == $new ) {
				continue;
			}
			else {
				if ( ! update_post_meta ( $post_id, $field, sanitize_key ( $new ) ) ) {
					add_post_meta( $post_id, $field, sanitize_key ( $new ), true );
				}
			}
		} // end foreach

		//Validation for header image extra options
		$title = $_POST['helena-featured-header-title'];
		delete_post_meta( $post_id, 'helena-featured-header-title' );
		if ( '' != $title ) {
			if ( ! update_post_meta ( $post_id, 'helena-featured-header-title', wp_kses_post ( $title ) ) ) {
				add_post_meta( $post_id, $field, wp_kses_post ( $title ), true );
			}
		}

		$content = $_POST['helena-featured-header-content'];
		delete_post_meta( $post_id, 'helena-featured-header-content' );
		if ( '' != $content ) {
			if ( ! update_post_meta ( $post_id, 'helena-featured-header-content', wp_kses_post ( $content ) ) ) {
				add_post_meta( $post_id, $field, wp_kses_post ( $content ), true );
			}
		}

		$button_text = $_POST['helena-featured-header-button-text'];
		delete_post_meta( $post_id, 'helena-featured-header-button-text' );
		if ( '' != $button_text ) {
			if ( ! update_post_meta ( $post_id, 'helena-featured-header-button-text', sanitize_text_field ( $button_text ) ) ) {
				add_post_meta( $post_id, $field, sanitize_text_field ( $button_text ), true );
			}
		}

		$button_link = $_POST['helena-featured-header-button-link'];
		delete_post_meta( $post_id, 'helena-featured-header-button-link' );
		if ( '' != $button_link ) {
			if ( ! update_post_meta ( $post_id, 'helena-featured-header-button-link', esc_url_raw( $button_link ) ) ) {
				add_post_meta( $post_id, $field, esc_url_raw ( $button_link ), true );
			}
		}

		$button_target = $_POST['helena-featured-header-button-target'];
		delete_post_meta( $post_id, 'helena-featured-header-button-target' );
		if ( '' != $button_target ) {
			if ( ! update_post_meta ( $post_id, 'helena-featured-header-button-target', ( bool ) $button_target ) ) {
				add_post_meta( $post_id, $field, ( bool ) $button_target, true );
			}
		}
	}
}

$helena_metabox = new helena_meta_box(
	'helena-options', 					//metabox id
	esc_html__( 'Helena Options', 'helena-pro' ), //metabox title
	array( 'page', 'post' )				//metabox post types
);